 
def newton_raphson(func, derivative, initial_guess, epsilon=1e-6, max_iterations=100):
    x = initial_guess
    for iteration in range(max_iterations):
        f_x = func(x)
        if abs(f_x) < epsilon:
            return x  # Converged
        df_x = derivative(x)
        if abs(df_x) < epsilon:
            return None  # Derivative too small, may not converge
        x = x - f_x / df_x
    return None  # Max iterations reached without convergence

# Example usage:
def my_function(x):
    return x**2 - 4  # Finding the square root of 4

def my_derivative(x):
    return 2 * x

root = newton_raphson(my_function, my_derivative, initial_guess=1.0)
if root is not None:
    print(f"Approximate root: {root}")
else:
    print("Newton-Raphson did not converge.")
